Subject: [bug#77956] [PATCH gnome-team 12/23] gnu: pango: Update to 1.56.3.

From: Liliana Marie Prikler <[email-masked]>
Date: Mon, 21 Apr 2025 15:47:48 +0200

* gnu/packages/gtk.scm (pango): Update to 1.56.3.
[arguments]: Convert to list of G-Expressions.
<#:configure-flags>: Add “-Dintrospection=enabled”.
---
 gnu/packages/gtk.scm | 30 +++++++++++++++++-------------
 1 file changed, 17 insertions(+), 13 deletions(-)

diff --git a/gnu/packages/gtk.scm b/gnu/packages/gtk.scm
index ac4400b226c..6228206bd70 100644
--- a/gnu/packages/gtk.scm
+++ b/gnu/packages/gtk.scm
@@ -401,7 +401,7 @@ (define-public libthai
 (define-public pango
   (package
     (name "pango")
-    (version "1.54.0")
+    (version "1.56.3")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnome/sources/pango/"
@@ -410,20 +410,24 @@ (define-public pango
               (patches (search-patches "pango-skip-libthai-test.patch"))
               (sha256
                (base32
-                "1n0y5l5wfq2a86dimraazvz1v9dvqdjkmpqgzkbk9rqy09syv7la"))))
+                "1494p8s2hj3snirpnd1lcz6pmcvjlb1r4zkz3d7d5n2wq8mja1i6"))))
     (build-system meson-build-system)
     (arguments
-     '(#:glib-or-gtk? #t             ; To wrap binaries and/or compile schemas
-       #:phases (modify-phases %standard-phases
-                  (add-after 'unpack 'disable-cantarell-tests
-                    (lambda _
-                      (substitute* "tests/meson.build"
-                        ;; XXX FIXME: These tests require "font-abattis-cantarell", but
-                        ;; adding it here would introduce a circular dependency.
-                        (("\\[ 'test-layout'.*") "")
-                        (("\\[ 'test-itemize'.*") "")
-                        (("\\[ 'test-font'.*") "")
-                        (("\\[ 'test-harfbuzz'.*") "")))))))
+     (list
+      #:glib-or-gtk? #t             ; To wrap binaries and/or compile schemas
+      #:configure-flags (if (target-hurd?)
+                            #~(list)
+                            #~(list "-Dintrospection=enabled"))
+      #:phases #~(modify-phases %standard-phases
+                   (add-after 'unpack 'disable-cantarell-tests
+                     (lambda _
+                       (substitute* "tests/meson.build"
+                         ;; XXX FIXME: These tests require "font-abattis-cantarell", but
+                         ;; adding it here would introduce a circular dependency.
+                         (("\\[ 'test-layout'.*") "")
+                         (("\\[ 'test-itemize'.*") "")
+                         (("\\[ 'test-font'.*") "")
+                         (("\\[ 'test-harfbuzz'.*") "")))))))
     (propagated-inputs
      ;; These are all in Requires or Requires.private of the '.pc' files.
      (list cairo
-- 
2.49.0